@@ -1,12 +1,16 @@
 #' Supported \pkg{mvgam} families
+#'
 #' @importFrom stats make.link dgamma pgamma rgamma qnorm plnorm runif pbeta dlnorm dpois
 #' @importFrom stats pnorm ppois plogis gaussian poisson Gamma dnbinom rnbinom dnorm dbeta
 #' @importFrom stats binomial rbinom pbinom dbinom qbinom qlogis
-#' @importFrom brms lognormal student beta_binomial bernoulli rstudent_t qstudent_t dstudent_t pstudent_t dbeta_binomial rbeta_binomial pbeta_binomial
+#' @importFrom brms lognormal student beta_binomial bernoulli rstudent_t qstudent_t dstudent_t
+#' @importFrom brms pstudent_t dbeta_binomial rbeta_binomial pbeta_binomial
 #' @importFrom mgcv betar nb
 #' @param link a specification for the family link function. At present these cannot
 #' be changed
+#'
 #' @param ... Arguments to be passed to the \pkg{mgcv} version of the associated functions
+#'
 #' @details \code{mvgam} currently supports the following standard observation families:
 #'\itemize{
 #'   \item \code{\link[stats]{gaussian}} with identity link, for real-valued data
@@ -40,10 +44,14 @@
 #' Only `poisson()`, `nb()`, and `tweedie()` are available if
 #' using `JAGS`. All families, apart from `tweedie()`, are supported if
 #' using `Stan`.
+#'
 #' @name mvgam_families
+#'
 #' @return Objects of class `family`
+#'
 #' @details Note that currently it is not possible to change the default link
-#' functions in `mvgam`, so any call to change these will be silently ignored
+#'
+#' functions in \pkg{mvgam}, so any call to change these will be silently ignored
 #' @author Nicholas J Clark
 #'
 NULL
@@ -119,141 +127,194 @@ beta_binomial = function(...) {
 }
 
 #' @rdname mvgam_families
+#'
 #' @examples
 #' \donttest{
-#' # Example showing how to set up N-mixture models
+#' # =============================================================================
+#' # N-mixture Models
+#' # =============================================================================
 #' set.seed(999)
-#'# Simulate observations for species 1, which shows a declining trend and 0.7 detection probability
-#'data.frame(site = 1,
-#'           # five replicates per year; six years
-#'           replicate = rep(1:5, 6),
-#'           time = sort(rep(1:6, 5)),
-#'           species = 'sp_1',
-#'           # true abundance declines nonlinearly
-#'           truth = c(rep(28, 5),
-#'                     rep(26, 5),
-#'                     rep(23, 5),
-#'                     rep(16, 5),
-#'                     rep(14, 5),
-#'                     rep(14, 5)),
-#'           # observations are taken with detection prob = 0.7
-#'           obs = c(rbinom(5, 28, 0.7),
-#'                   rbinom(5, 26, 0.7),
-#'                   rbinom(5, 23, 0.7),
-#'                   rbinom(5, 15, 0.7),
-#'                   rbinom(5, 14, 0.7),
-#'                   rbinom(5, 14, 0.7))) %>%
-#'  # add 'series' information, which is an identifier of site, replicate and species
-#'  dplyr::mutate(series = paste0('site_', site,
-#'                                '_', species,
-#'                                '_rep_', replicate),
-#'                time = as.numeric(time),
-#'                # add a 'cap' variable that defines the maximum latent N to
-#'                # marginalize over when estimating latent abundance; in other words
-#'                # how large do we realistically think the true abundance could be?
-#'                cap = 80) %>%
-#'  dplyr::select(- replicate) -> testdat
 #'
-#'# Now add another species that has a different temporal trend and a smaller
-#'# detection probability (0.45 for this species)
-#'testdat = testdat %>%
-#'  dplyr::bind_rows(data.frame(site = 1,
-#'                              replicate = rep(1:5, 6),
-#'                              time = sort(rep(1:6, 5)),
-#'                              species = 'sp_2',
-#'                              truth = c(rep(4, 5),
-#'                                        rep(7, 5),
-#'                                        rep(15, 5),
-#'                                        rep(16, 5),
-#'                                        rep(19, 5),
-#'                                        rep(18, 5)),
-#'                              obs = c(rbinom(5, 4, 0.45),
-#'                                      rbinom(5, 7, 0.45),
-#'                                      rbinom(5, 15, 0.45),
-#'                                      rbinom(5, 16, 0.45),
-#'                                      rbinom(5, 19, 0.45),
-#'                                      rbinom(5, 18, 0.45))) %>%
-#'                     dplyr::mutate(series = paste0('site_', site,
-#'                                                   '_', species,
-#'                                                   '_rep_', replicate),
-#'                                   time = as.numeric(time),
-#'                                   cap = 50) %>%
-#'                     dplyr::select(-replicate))
+#' # Simulate observations for species 1, which shows a declining trend and
+#' # 0.7 detection probability
+#' data.frame(
+#'   site = 1,
+#'   # five replicates per year; six years
+#'   replicate = rep(1:5, 6),
+#'   time = sort(rep(1:6, 5)),
+#'   species = 'sp_1',
+#'   # true abundance declines nonlinearly
+#'   truth = c(
+#'     rep(28, 5),
+#'     rep(26, 5),
+#'     rep(23, 5),
+#'     rep(16, 5),
+#'     rep(14, 5),
+#'     rep(14, 5)
+#'   ),
+#'   # observations are taken with detection prob = 0.7
+#'   obs = c(
+#'     rbinom(5, 28, 0.7),
+#'     rbinom(5, 26, 0.7),
+#'     rbinom(5, 23, 0.7),
+#'     rbinom(5, 15, 0.7),
+#'     rbinom(5, 14, 0.7),
+#'     rbinom(5, 14, 0.7)
+#'   )
+#' ) %>%
+#'   # add 'series' information, which is an identifier of site, replicate
+#'   # and species
+#'   dplyr::mutate(
+#'     series = paste0(
+#'       'site_', site,
+#'       '_', species,
+#'       '_rep_', replicate
+#'     ),
+#'     time = as.numeric(time),
+#'     # add a 'cap' variable that defines the maximum latent N to
+#'     # marginalize over when estimating latent abundance; in other words
+#'     # how large do we realistically think the true abundance could be?
+#'     cap = 80
+#'   ) %>%
+#'   dplyr::select(-replicate) -> testdat
+#'
+#' # Now add another species that has a different temporal trend and a
+#' # smaller detection probability (0.45 for this species)
+#' testdat <- testdat %>%
+#'   dplyr::bind_rows(
+#'     data.frame(
+#'       site = 1,
+#'       replicate = rep(1:5, 6),
+#'       time = sort(rep(1:6, 5)),
+#'       species = 'sp_2',
+#'       truth = c(
+#'         rep(4, 5),
+#'         rep(7, 5),
+#'         rep(15, 5),
+#'         rep(16, 5),
+#'         rep(19, 5),
+#'         rep(18, 5)
+#'       ),
+#'       obs = c(
+#'         rbinom(5, 4, 0.45),
+#'         rbinom(5, 7, 0.45),
+#'         rbinom(5, 15, 0.45),
+#'         rbinom(5, 16, 0.45),
+#'         rbinom(5, 19, 0.45),
+#'         rbinom(5, 18, 0.45)
+#'       )
+#'     ) %>%
+#'       dplyr::mutate(
+#'         series = paste0(
+#'           'site_', site,
+#'           '_', species,
+#'           '_rep_', replicate
+#'         ),
+#'         time = as.numeric(time),
+#'         cap = 50
+#'       ) %>%
+#'       dplyr::select(-replicate)
+#'   )
 #'
 #' # series identifiers
-#' testdat$species <- factor(testdat$species,
-#'                           levels = unique(testdat$species))
-#' testdat$series <- factor(testdat$series,
-#'                          levels = unique(testdat$series))
+#' testdat$species <- factor(
+#'   testdat$species,
+#'   levels = unique(testdat$species)
+#' )
+#' testdat$series <- factor(
+#'   testdat$series,
+#'   levels = unique(testdat$series)
+#' )
 #'
 #' # The trend_map to state how replicates are structured
 #' testdat %>%
-#' # each unique combination of site*species is a separate process
-#'dplyr::mutate(trend = as.numeric(factor(paste0(site, species)))) %>%
-#'  dplyr::select(trend, series) %>%
-#'  dplyr::distinct() -> trend_map
-#'trend_map
+#'   # each unique combination of site*species is a separate process
+#'   dplyr::mutate(
+#'     trend = as.numeric(factor(paste0(site, species)))
+#'   ) %>%
+#'   dplyr::select(trend, series) %>%
+#'   dplyr::distinct() -> trend_map
+#' trend_map
 #'
 #' # Fit a model
 #' mod <- mvgam(
-#'             # the observation formula sets up linear predictors for
-#'             # detection probability on the logit scale
-#'             formula = obs ~ species - 1,
+#'   # the observation formula sets up linear predictors for
+#'   # detection probability on the logit scale
+#'   formula = obs ~ species - 1,
 #'
-#'             # the trend_formula sets up the linear predictors for
-#'             # the latent abundance processes on the log scale
-#'             trend_formula = ~ s(time, by = trend, k = 4) + species,
+#'   # the trend_formula sets up the linear predictors for
+#'   # the latent abundance processes on the log scale
+#'   trend_formula = ~ s(time, by = trend, k = 4) + species,
 #'
-#'             # the trend_map takes care of the mapping
-#'             trend_map = trend_map,
+#'   # the trend_map takes care of the mapping
+#'   trend_map = trend_map,
 #'
-#'             # nmix() family and data
-#'             family = nmix(),
-#'             data = testdat,
+#'   # nmix() family and data
+#'   family = nmix(),
+#'   data = testdat,
 #'
-#'             # priors can be set in the usual way
-#'             priors = c(prior(std_normal(), class = b),
-#'                        prior(normal(1, 1.5), class = Intercept_trend)),
-#'             chains = 2)
+#'   # priors can be set in the usual way
+#'   priors = c(
+#'     prior(std_normal(), class = b),
+#'     prior(normal(1, 1.5), class = Intercept_trend)
+#'   ),
+#'   chains = 2
+#' )
 #'
 #' # The usual diagnostics
 #' summary(mod)
 #'
 #' # Plotting conditional effects
-#' library(ggplot2); library(marginaleffects)
-#' plot_predictions(mod, condition = 'species',
-#'                  type = 'detection') +
-#'      ylab('Pr(detection)') +
-#'      ylim(c(0, 1)) +
-#'      theme_classic() +
-#'      theme(legend.position = 'none')
+#' library(ggplot2)
+#'
+#' plot_predictions(
+#'   mod,
+#'   condition = 'species',
+#'   type = 'detection'
+#' ) +
+#'   ylab('Pr(detection)') +
+#'   ylim(c(0, 1)) +
+#'   theme_classic() +
+#'   theme(legend.position = 'none')
+#'
+#' # =============================================================================
+#' # Binomial Models
+#' # =============================================================================
 #'
-#' # Example showcasing how cbind() is needed for Binomial observations
 #' # Simulate two time series of Binomial trials
 #' trials <- sample(c(20:25), 50, replace = TRUE)
 #' x <- rnorm(50)
-#' detprob1 <- plogis(-0.5 + 0.9*x)
-#' detprob2 <- plogis(-0.1 -0.7*x)
-#' dat <- rbind(data.frame(y = rbinom(n = 50, size = trials, prob = detprob1),
-#'                         time = 1:50,
-#'                         series = 'series1',
-#'                         x = x,
-#'                         ntrials = trials),
-#'              data.frame(y = rbinom(n = 50, size = trials, prob = detprob2),
-#'                         time = 1:50,
-#'                         series = 'series2',
-#'                         x = x,
-#'                         ntrials = trials))
+#' detprob1 <- plogis(-0.5 + 0.9 * x)
+#' detprob2 <- plogis(-0.1 - 0.7 * x)
+#' dat <- rbind(
+#'   data.frame(
+#'     y = rbinom(n = 50, size = trials, prob = detprob1),
+#'     time = 1:50,
+#'     series = 'series1',
+#'     x = x,
+#'     ntrials = trials
+#'   ),
+#'   data.frame(
+#'     y = rbinom(n = 50, size = trials, prob = detprob2),
+#'     time = 1:50,
+#'     series = 'series2',
+#'     x = x,
+#'     ntrials = trials
+#'   )
+#' )
 #' dat <- dplyr::mutate(dat, series = as.factor(series))
 #' dat <- dplyr::arrange(dat, time, series)
 #'
 #' # Fit a model using the binomial() family; must specify observations
 #' # and number of trials in the cbind() wrapper
-#' mod <- mvgam(cbind(y, ntrials) ~ series + s(x, by = series),
-#'              family = binomial(),
-#'              data = dat)
+#' mod <- mvgam(
+#'   cbind(y, ntrials) ~ series + s(x, by = series),
+#'   family = binomial(),
+#'   data = dat
+#' )
 #' summary(mod)
 #' }
+#'
 #' @export
 nmix = function(link = 'log') {
   linktemp <- make.link('log')
@@ -409,7 +470,9 @@ mvgam_predict = function(
         )
       }
     } else if (type == 'latent_N') {
-      if (missing(min_cap)) min_cap <- 0
+      if (missing(min_cap)) {
+        min_cap <- 0
+      }
       min_cap <- as.vector(min_cap)
       if (missing(truth)) {
         out <- extraDistr::rtpois(
@@ -1022,40 +1085,88 @@ family_invlinks = function(family) {
 }
 
 #' Parameters to monitor / extract depending on the observation family
+#' @param family Character string of family name
+#' @return Named list with parameter names and descriptive labels
+#' @noRd
+family_param_info = function(family) {
+  # Define family parameter specifications
+  family_specs <- list(
+    gaussian = list(
+      param_names = "sigma_obs",
+      labels = "observation_error"
+    ),
+    lognormal = list(
+      param_names = "sigma_obs",
+      labels = "log_observation_error"
+    ),
+    student = list(
+      param_names = c("sigma_obs", "nu"),
+      labels = c("observation_error", "observation_df")
+    ),
+    Gamma = list(
+      param_names = "shape",
+      labels = "observation_shape"
+    ),
+    beta = list(
+      param_names = "phi",
+      labels = "observation_precision"
+    ),
+    beta_binomial = list(
+      param_names = "phi",
+      labels = "observation_dispersion"
+    ),
+    "negative binomial" = list(
+      param_names = "phi",
+      labels = "observation_dispersion"
+    ),
+    tweedie = list(
+      param_names = "phi",
+      labels = "observation_dispersion"
+    ),
+    nmix = list(
+      param_names = "detprob",
+      labels = "detection_probability"
+    ),
+    poisson = list(
+      param_names = character(0),
+      labels = character(0)
+    ),
+    binomial = list(
+      param_names = character(0),
+      labels = character(0)
+    ),
+    bernoulli = list(
+      param_names = character(0),
+      labels = character(0)
+    )
+  )
+
+  # Return specification for the given family
+  spec <- family_specs[[family]]
+  if (is.null(spec)) {
+    # Default for unknown families
+    spec <- list(
+      param_names = character(0),
+      labels = character(0)
+    )
+  }
+
+  return(spec)
+}
+
+#' Parameters to monitor / extract depending on the observation family
+#' (deprecated Use family_param_info() instead)
 #' @noRd
 family_par_names = function(family) {
-  if (family %in% c('gaussian', 'lognormal')) {
-    out <- c('sigma_obs')
-  }
-
-  if (family == 'student') {
-    out <- c('sigma_obs', 'nu')
-  }
-
-  if (family == 'Gamma') {
-    out <- c('shape')
-  }
-
-  if (family %in% c('beta', 'beta_binomial', 'negative binomial', 'tweedie')) {
-    out <- c('phi')
-  }
-
-  if (family %in% c('poisson', 'binomial', 'bernoulli')) {
-    out <- c()
-  }
-
-  if (family == 'nmix') {
-    out <- c('detprob')
-  }
-
-  return(out)
+  # Maintain backward compatibility by extracting param_names from new function
+  family_param_info(family)$param_names
 }
 
 #' Define which parameters to monitor / extract
 #' @noRd
 extract_family_pars = function(object, newdata = NULL) {
   # Get names of parameters to extract
-  pars_to_extract <- family_par_names(object$family)
+  pars_to_extract <- family_param_info(object$family)$param_names
 
   # Extract into a named list
   if (length(pars_to_extract) > 0) {
