@@ -1,73 +1,115 @@
-#'@title Extract or compute hindcasts and forecasts for a fitted \code{mvgam} object
-#'@name forecast.mvgam
-#'@importFrom stats predict
-#'@importFrom rlang missing_arg
-#'@inheritParams predict.mvgam
-#'@param newdata Optional \code{dataframe} or \code{list} of test data containing the same variables
-#'that were included in the original `data` used to fit the model. If included, the
-#'covariate information in \code{newdata} will be used to generate forecasts from the fitted model equations. If
-#'this same \code{newdata} was originally included in the call to \code{mvgam}, then forecasts have already been
-#'produced by the generative model and these will simply be extracted and plotted. However if no \code{newdata} was
-#'supplied to the original model call, an assumption is made that the \code{newdata} supplied here comes sequentially
-#'after the data supplied in the original model (i.e. we assume there is no time gap between the last
-#'observation of series 1 in the original data and the first observation for series 1 in \code{newdata})
-#'@param data_test Deprecated. Still works in place of \code{newdata} but users are recommended to use
-#'\code{newdata} instead for more seamless integration into `R` workflows
-#'@param n_cores Deprecated. Parallel processing is no longer supported
-#'@param ... Ignored
-#'@details Posterior predictions are drawn from the fitted \code{mvgam} and used to simulate a forecast distribution
-#'@return An object of class \code{mvgam_forecast} containing hindcast and forecast distributions.
-#'See \code{\link{mvgam_forecast-class}} for details.
-#'@seealso \code{\link{hindcast}}, \code{\link{score}}, \code{\link{ensemble}}
-#'@export
-forecast <- function(object, ...) {
-  UseMethod("forecast", object)
-}
+#' @importFrom generics forecast
+#' @export
+generics::forecast
 
-#'@rdname forecast.mvgam
-#'@method forecast mvgam
+#' @title Extract or compute hindcasts and forecasts for a fitted
+#'   \code{mvgam} object
+#'
+#' @name forecast.mvgam
+#'
+#' @method forecast mvgam
+#'
+#' @importFrom stats predict
+#'
+#' @importFrom rlang missing_arg
+#'
+#' @inheritParams predict.mvgam
+#'
+#' @param newdata Optional \code{dataframe} or \code{list} of test data
+#'   containing the same variables that were included in the original `data`
+#'   used to fit the model. If included, the covariate information in
+#'   \code{newdata} will be used to generate forecasts from the fitted model
+#'   equations. If this same \code{newdata} was originally included in the call
+#'   to \code{mvgam}, then forecasts have already been produced by the
+#'   generative model and these will simply be extracted and plotted. However
+#'   if no \code{newdata} was supplied to the original model call, an
+#'   assumption is made that the \code{newdata} supplied here comes
+#'   sequentially after the data supplied in the original model (i.e. we
+#'   assume there is no time gap between the last observation of series 1 in
+#'   the original data and the first observation for series 1 in
+#'   \code{newdata})
+#'
+#' @param data_test Deprecated. Still works in place of \code{newdata} but
+#'   users are recommended to use \code{newdata} instead for more seamless
+#'   integration into `R` workflows
+#'
+#' @param n_cores Deprecated. Parallel processing is no longer supported
+#'
+#' @param ... Ignored
+#'
+#' @details Posterior predictions are drawn from the fitted \code{mvgam} and
+#'   used to simulate a forecast distribution
+#'
+#' @return An object of class \code{mvgam_forecast} containing hindcast and
+#'   forecast distributions. See \code{\link{mvgam_forecast-class}} for
+#'   details.
+#'
+#' @seealso [hindcast.mvgam()], [plot.mvgam_forecast()],
+#'   [summary.mvgam_forecast()], [score.mvgam_forecast()]
+#'   [ensemble.mvgam_forecast()]
+#'
 #' @examples
 #' \donttest{
-#' simdat <- sim_mvgam(n_series = 3, trend_model = AR())
-#' mod <- mvgam(y ~ s(season, bs = 'cc', k = 6),
-#'              trend_model = AR(),
-#'              noncentred = TRUE,
-#'              data = simdat$data_train,
-#'              chains = 2,
-#'              silent = 2)
+#'   # Simulate data with 3 series and AR trend model
+#'   simdat <- sim_mvgam(n_series = 3, trend_model = AR())
 #'
-#' # Hindcasts on response scale
-#' hc <- hindcast(mod)
-#' str(hc)
-#' plot(hc, series = 1)
-#' plot(hc, series = 2)
-#' plot(hc, series = 3)
+#'   # Fit mvgam model
+#'   mod <- mvgam(
+#'     y ~ s(season, bs = 'cc', k = 6),
+#'     trend_model = AR(),
+#'     noncentred = TRUE,
+#'     data = simdat$data_train,
+#'     chains = 2,
+#'     silent = 2
+#'   )
 #'
-#' # Forecasts on response scale
-#' fc <- forecast(mod,
-#'                newdata = simdat$data_test)
-#' str(fc)
-#' plot(fc, series = 1)
-#' plot(fc, series = 2)
-#' plot(fc, series = 3)
+#'   # Hindcasts on response scale
+#'   hc <- hindcast(mod)
+#'   str(hc)
 #'
-#' # Forecasts as expectations
-#' fc <- forecast(mod,
-#'                newdata = simdat$data_test,
-#'                type = 'expected')
-#' plot(fc, series = 1)
-#' plot(fc, series = 2)
-#' plot(fc, series = 3)
+#'   # Use summary() to extract hindcasts / forecasts for custom plotting
+#'   head(summary(hc), 12)
 #'
-#' # Dynamic trend extrapolations
-#' fc <- forecast(mod,
-#'                newdata = simdat$data_test,
-#'                type = 'trend')
-#' plot(fc, series = 1)
-#' plot(fc, series = 2)
-#' plot(fc, series = 3)
+#'   # Or just use the plot() function for quick plots
+#'   plot(hc, series = 1)
+#'   plot(hc, series = 2)
+#'   plot(hc, series = 3)
+#'
+#'   # Forecasts on response scale
+#'   fc <- forecast(
+#'     mod,
+#'     newdata = simdat$data_test
+#'   )
+#'   str(fc)
+#'   head(summary(fc), 12)
+#'   plot(fc, series = 1)
+#'   plot(fc, series = 2)
+#'   plot(fc, series = 3)
+#'
+#'   # Forecasts as expectations
+#'   fc <- forecast(
+#'     mod,
+#'     newdata = simdat$data_test,
+#'     type = 'expected'
+#'   )
+#'   head(summary(fc), 12)
+#'   plot(fc, series = 1)
+#'   plot(fc, series = 2)
+#'   plot(fc, series = 3)
+#'
+#'   # Dynamic trend extrapolations
+#'   fc <- forecast(
+#'     mod,
+#'     newdata = simdat$data_test,
+#'     type = 'trend'
+#'   )
+#'   head(summary(fc), 12)
+#'   plot(fc, series = 1)
+#'   plot(fc, series = 2)
+#'   plot(fc, series = 3)
 #' }
-#'@export
+#'
+#' @export
 forecast.mvgam = function(
   object,
   newdata,
@@ -183,6 +225,7 @@ forecast.mvgam = function(
     } else {
       data_test <- data_test[idx, ]
     }
+    object$test_data <- data_test
   }
 
   # Only compute forecasts if they don't already exist!
@@ -709,6 +752,31 @@ forecast.mvgam = function(
     names(series_test) <- levels(data_train$series)
   }
 
+  series_train_times <- lapply(seq_len(n_series), function(series) {
+    s_name <- levels(object$obs_data$series)[series]
+    data.frame(
+      series = object$obs_data$series,
+      time = object$obs_data$time,
+      y = object$obs_data$y
+    ) %>%
+      dplyr::filter(series == s_name) %>%
+      dplyr::arrange(time) %>%
+      dplyr::pull(time)
+  })
+  names(series_train_times) <- levels(data_train$series)
+
+  series_test_times <- lapply(seq_len(n_series), function(series) {
+    s_name <- levels(object$obs_data$series)[series]
+    data.frame(
+      series = data_test$series,
+      time = data_test$time
+    ) %>%
+      dplyr::filter(series == s_name) %>%
+      dplyr::arrange(time) %>%
+      dplyr::pull(time)
+  })
+  names(series_test_times) <- levels(data_train$series)
+
   series_fcs <- structure(
     list(
       call = object$call,
@@ -729,9 +797,9 @@ forecast.mvgam = function(
         levels = levels(data_train$series)
       ),
       train_observations = series_obs,
-      train_times = unique(data_train$index..time..index),
+      train_times = series_train_times,
       test_observations = series_test,
-      test_times = unique(data_test$index..time..index),
+      test_times = series_test_times,
       hindcasts = series_hcs,
       forecasts = series_fcs
     ),
