@@ -242,7 +242,9 @@ make_gp_additions = function(
   # the gp() eigenfunctions
   coefs_replace <- list()
   for (x in gp_terms) {
-    label <- attr(terms(formula(mgcv_model)), 'term.labels')[x]
+    label <- attr(terms(formula(mgcv_model), keep.order = TRUE), 'term.labels')[
+      x
+    ]
     s_attributes <- eval(rlang::parse_expr(label))
     if (s_attributes$by != 'NA') {
       if (grepl('ti(', label, fixed = TRUE)) {
@@ -479,6 +481,16 @@ gp_to_s <- function(formula, data, family) {
   gp_details <- get_gp_attributes(formula, data, family)
   termlabs <- attr(terms(formula, keep.order = TRUE), 'term.labels')
 
+  # Check for offsets as well
+  off_names <- grep(
+    'offset',
+    rownames(attr(terms.formula(formula), 'factors')),
+    value = TRUE
+  )
+  if (length(off_names) > 0L) {
+    termlabs <- c(termlabs, off_names)
+  }
+
   # Replace the gp() terms with s() for constructing the initial model
   which_gp <- which_are_gp(formula)
   response <- rlang::f_lhs(formula)
@@ -653,7 +665,9 @@ get_gp_attributes = function(formula, data, family = gaussian()) {
           def_rho_4 = NA,
           def_alpha = def_alpha
         )
-        if (length(def_rho) > 2L) out$def_rho_3 <- def_rho[3]
+        if (length(def_rho) > 2L) {
+          out$def_rho_3 <- def_rho[3]
+        }
         if (length(def_rho) > 3L) out$def_rho_4 <- def_rho[4]
       } else {
         out <- data.frame(
@@ -1191,69 +1205,74 @@ add_gp_spd_funs = function(model_file, kernel) {
   model_file <- readLines(textConnection(model_file), n = -1)
 }
 
+#' Evaluate Laplacian eigenfunction for a given GP basis function
+#' @noRd
+phi = function(boundary, m, centred_covariate) {
+  1 /
+    sqrt(boundary) *
+    sin((m * pi) / (2 * boundary) * (centred_covariate + boundary))
+}
+
+#' Evaluate eigenvalues for a given GP basis function
+#' @noRd
+lambda = function(boundary, m) {
+  ((m * pi) / (2 * boundary))^2
+}
+
+#' Spectral density squared exponential Gaussian Process kernel
+#' @noRd
+spd = function(alpha_gp, rho_gp, eigenvalues) {
+  (alpha_gp^2) *
+    sqrt(2 * pi) *
+    rho_gp *
+    exp(-0.5 * (rho_gp^2) * (eigenvalues^2))
+}
+
+#' @noRd
+sim_hilbert_gp = function(
+  alpha_gp,
+  rho_gp,
+  b_gp,
+  last_trends,
+  fc_times,
+  train_times,
+  mean_train_times
+) {
+  num_gp_basis <- length(b_gp)
+
+  # Get vector of eigenvalues of covariance matrix
+  eigenvalues <- vector()
+  for (m in 1:num_gp_basis) {
+    eigenvalues[m] <- lambda(
+      boundary = (5.0 / 4) *
+        (max(train_times) - min(train_times)),
+      m = m
+    )
+  }
+
+  # Get vector of eigenfunctions
+  eigenfunctions <- matrix(NA, nrow = length(fc_times), ncol = num_gp_basis)
+  for (m in 1:num_gp_basis) {
+    eigenfunctions[, m] <- phi(
+      boundary = (5.0 / 4) *
+        (max(train_times) - min(train_times)),
+      m = m,
+      centred_covariate = fc_times - mean_train_times
+    )
+  }
+
+  # Compute diagonal of covariance matrix
+  diag_SPD <- sqrt(spd(alpha_gp = alpha_gp, rho_gp = rho_gp, sqrt(eigenvalues)))
+
+  # Compute GP trend forecast
+  as.vector((diag_SPD * b_gp) %*% t(eigenfunctions))
+}
+
 #### Old gp() prepping functions; these are now redundant because
 # brms is used to evaluate gp() effects and produce the relevant
 # eigenfunctions / eigenvalues, but keeping the functions here for
 # now in case they are needed for later work ####
 
-#' #' Evaluate Laplacian eigenfunction for a given GP basis function
-#' #' @noRd
-#' phi = function(boundary, m, centred_covariate) {
-#'   1 / sqrt(boundary) * sin((m * pi)/(2 * boundary) *
-#'                              (centred_covariate + boundary))
-#' }
-#'
-#' #' Evaluate eigenvalues for a given GP basis function
-#' #' @noRd
-#' lambda = function(boundary, m) {
-#'   ((m * pi)/(2 * boundary))^2
-#' }
-#'
-#' #' Spectral density squared exponential Gaussian Process kernel
-#' #' @noRd
-#' spd = function(alpha_gp, rho_gp, eigenvalues) {
-#'   (alpha_gp^2) * sqrt(2 * pi) * rho_gp *
-#'     exp(-0.5 * (rho_gp^2) * (eigenvalues^2))
-#' }
-#'
-#' #' @noRd
-#' sim_hilbert_gp = function(alpha_gp,
-#'                           rho_gp,
-#'                           b_gp,
-#'                           last_trends,
-#'                           fc_times,
-#'                           train_times,
-#'                           mean_train_times){
-#'
-#'   num_gp_basis <- length(b_gp)
-#'
-#'   # Get vector of eigenvalues of covariance matrix
-#'   eigenvalues <- vector()
-#'   for(m in 1:num_gp_basis){
-#'     eigenvalues[m] <- lambda(boundary = (5.0/4) *
-#'                                (max(train_times) - min(train_times)),
-#'                              m = m)
-#'   }
-#'
-#'   # Get vector of eigenfunctions
-#'   eigenfunctions <- matrix(NA, nrow = length(fc_times),
-#'                            ncol = num_gp_basis)
-#'   for(m in 1:num_gp_basis){
-#'     eigenfunctions[, m] <- phi(boundary = (5.0/4) *
-#'                                  (max(train_times) - min(train_times)),
-#'                                m = m,
-#'                                centred_covariate = fc_times - mean_train_times)
-#'   }
-#'
-#'   # Compute diagonal of covariance matrix
-#'   diag_SPD <- sqrt(spd(alpha_gp = alpha_gp,
-#'                        rho_gp = rho_gp,
-#'                        sqrt(eigenvalues)))
-#'
-#'   # Compute GP trend forecast
-#'   as.vector((diag_SPD * b_gp) %*% t(eigenfunctions))
-#' }
-
 #' #' Compute the mth eigen function of an approximate GP
 #' #' Credit to Paul Burkner from brms: https://github.com/paul-buerkner/brms/R/formula-gp.R#L289
 #' #' @noRd
