@@ -3,12 +3,13 @@
 #'@importFrom stats predict
 #'@inheritParams predict.mvgam
 #'@param ... Ignored
-#'@details Posterior retrodictions are drawn from the fitted \code{mvgam} and
-#'organized into a convenient format
+#'@details Posterior hindcasts (i.e. retrodictions) are drawn from the fitted \code{mvgam} and
+#'organized into a convenient format for plotting
 #'@return An object of class \code{mvgam_forecast} containing hindcast distributions.
 #'See \code{\link{mvgam_forecast-class}} for details.
 #'
-#'@seealso \code{\link{forecast.mvgam}}
+#'@seealso [plot.mvgam_forecast()], [summary.mvgam_forecast()],
+#'[forecast.mvgam()], [fitted.mvgam()], [predict.mvgam()]
 #'@export
 hindcast <- function(object, ...) {
   UseMethod("hindcast", object)
@@ -29,20 +30,21 @@ hindcast <- function(object, ...) {
 #' # Hindcasts on response scale
 #' hc <- hindcast(mod)
 #' str(hc)
+#' head(summary(hc), 12)
 #' plot(hc, series = 1)
 #' plot(hc, series = 2)
 #' plot(hc, series = 3)
 #'
 #' # Hindcasts as expectations
 #' hc <- hindcast(mod, type = 'expected')
-#' str(hc)
+#' head(summary(hc), 12)
 #' plot(hc, series = 1)
 #' plot(hc, series = 2)
 #' plot(hc, series = 3)
 #'
 #' # Estimated latent trends
 #' hc <- hindcast(mod, type = 'trend')
-#' str(hc)
+#' head(summary(hc), 12)
 #' plot(hc, series = 1)
 #' plot(hc, series = 2)
 #' plot(hc, series = 3)
@@ -207,6 +209,19 @@ hindcast.mvgam = function(object, type = 'response', ...) {
   })
   names(series_obs) <- levels(data_train$series)
 
+  series_train_times <- lapply(seq_len(n_series), function(series) {
+    s_name <- levels(data_train$series)[series]
+    data.frame(
+      series = data_train$series,
+      time = data_train$time,
+      y = data_train$y
+    ) %>%
+      dplyr::filter(series == s_name) %>%
+      dplyr::arrange(time) %>%
+      dplyr::pull(time)
+  })
+  names(series_train_times) <- levels(data_train$series)
+
   series_fcs <- structure(
     list(
       call = object$call,
@@ -219,7 +234,7 @@ hindcast.mvgam = function(object, type = 'response', ...) {
       type = type,
       series_names = levels(data_train$series),
       train_observations = series_obs,
-      train_times = unique(data_train$time),
+      train_times = series_train_times,
       test_observations = NULL,
       test_times = NULL,
       hindcasts = series_hcs,
