@@ -1,33 +1,44 @@
 #'Fit Joint Species Distribution Models in \pkg{mvgam}
 #'
-#'This function sets up a Joint Species Distribution Model whereby the residual associations among
-#'species can be modelled in a reduced-rank format using a set of latent factors. The factor
-#'specification is extremely flexible, allowing users to include spatial, temporal or any other type
-#'of predictor effects to more efficiently capture unmodelled residual associations, while the
-#'observation model can also be highly flexible (including all smooth, GP and other effects that
-#'\pkg{mvgam} can handle)
+#'This function sets up a Joint Species Distribution Model whereby the residual
+#'associations among species can be modelled in a reduced-rank format using a
+#'set of latent factors. The factor specification is extremely flexible,
+#'allowing users to include spatial, temporal or any other type of predictor
+#'effects to more efficiently capture unmodelled residual associations, while
+#'the observation model can also be highly flexible (including all smooth, GP
+#'and other effects that \pkg{mvgam} can handle)
 #'
 #'@inheritParams mvgam
 #'@inheritParams ZMVN
-#'@param formula A \code{formula} object specifying the GAM observation model formula. These are exactly like the formula
-#'for a GLM except that smooth terms, `s()`, `te()`, `ti()`, `t2()`, as well as time-varying
-#'`dynamic()` terms, nonparametric `gp()` terms and offsets using `offset()`, can be added to the right hand side
-#'to specify that the linear predictor depends on smooth functions of predictors
-#'(or linear functionals of these). Details of the formula syntax used by \pkg{mvgam}
-#'can be found in \code{\link{mvgam_formulae}}
+#'
+#'@param formula A \code{formula} object specifying the GAM observation model
+#'  formula. These are exactly like the formula for a GLM except that smooth
+#'  terms, `s()`, `te()`, `ti()`, `t2()`, as well as time-varying `dynamic()`
+#'  terms, nonparametric `gp()` terms and offsets using `offset()`, can be
+#'  added to the right hand side to specify that the linear predictor depends
+#'  on smooth functions of predictors (or linear functionals of these).
+#'  Details of the formula syntax used by \pkg{mvgam} can be found in
+#'  \code{\link{mvgam_formulae}}
+#'
 #'@param factor_formula A \code{formula} object specifying the linear predictor
-#'effects for the latent factors. Use `by = trend` within calls to functional terms
-#'(i.e. `s()`, `te()`, `ti()`, `t2()`, `dynamic()`, or `gp()`) to ensure that each factor
-#'captures a different axis of variation. See the example below as an illustration
-#'@param factor_knots An optional \code{list} containing user specified knot values to
-#' be used for basis construction of any smooth terms in `factor_formula`.
-#'For most bases the user simply supplies the knots to be used, which must match up with the `k` value supplied
-#'(note that the number of knots is not always just `k`). Different terms can use different numbers of knots,
-#'unless they share a covariate
-#'@param data A \code{dataframe} or \code{list} containing the model response variable and covariates
-#'required by the GAM \code{formula} and \code{factor_formula} objects
-#'@param family \code{family} specifying the observation family for the outcomes. Currently supported
-#'families are:
+#'  effects for the latent factors. Use `by = trend` within calls to functional
+#'  terms (i.e. `s()`, `te()`, `ti()`, `t2()`, `dynamic()`, or `gp()`) to
+#'  ensure that each factor captures a different axis of variation. See the
+#'  example below as an illustration
+#'
+#'@param factor_knots An optional \code{list} containing user specified knot
+#'  values to be used for basis construction of any smooth terms in
+#'  `factor_formula`. For most bases the user simply supplies the knots to be
+#'  used, which must match up with the `k` value supplied (note that the
+#'  number of knots is not always just `k`). Different terms can use different
+#'  numbers of knots, unless they share a covariate
+#'
+#'@param data A \code{dataframe} or \code{list} containing the model response
+#'  variable and covariates required by the GAM \code{formula} and
+#'  \code{factor_formula} objects
+#'
+#'@param family \code{family} specifying the observation family for the
+#'  outcomes. Currently supported families are:
 #'\itemize{
 #'   \item`gaussian()` for real-valued data
 #'   \item`betar()` for proportional data on `(0,1)`
@@ -37,75 +48,136 @@
 #'   \item`bernoulli()` for binary data
 #'   \item`poisson()` for count data
 #'   \item`nb()` for overdispersed count data
-#'   \item`binomial()` for count data with imperfect detection when the number of trials is known;
-#'   note that the `cbind()` function must be used to bind the discrete observations and the discrete number
-#'   of trials
+#'   \item`binomial()` for count data with imperfect detection when the number
+#'     of trials is known; note that the `cbind()` function must be used to
+#'     bind the discrete observations and the discrete number of trials
 #'   \item`beta_binomial()` as for `binomial()` but allows for overdispersion}
 #'Default is `poisson()`. See \code{\link{mvgam_families}} for more details
-#' @param species The unquoted name of the `factor` variable that indexes
-#' the different response units in `data` (usually `'species'` in a JSDM).
-#' Defaults to `series` to be consistent with other `mvgam` models
+#'
+#' @param species The unquoted name of the `factor` variable that indexes the
+#'   different response units in `data` (usually `'species'` in a JSDM).
+#'   Defaults to `series` to be consistent with other `mvgam` models
+#'
 #'@param n_lv \code{integer} the number of latent factors to use for modelling
-#'residual associations.
-#'Cannot be `> n_species`. Defaults arbitrarily to `2`
-#'@param threads \code{integer} Experimental option to use multithreading for within-chain
-#'parallelisation in \code{Stan}. We recommend its use only if you are experienced with
-#'\code{Stan}'s `reduce_sum` function and have a slow running model that cannot be sped
-#'up by any other means. Currently works for all families when using \code{Cmdstan}
-#'as the backend
-#'@param priors An optional \code{data.frame} with prior
-#'definitions (in Stan syntax) or, preferentially, a vector containing
-#' objects of class `brmsprior` (see. \code{\link[brms]{prior}} for details).
-#' See [get_mvgam_priors] and for more information on changing default prior distributions
+#'  residual associations. Cannot be `> n_species`. Defaults arbitrarily to `2`
+#'
+#'@param threads \code{integer} Experimental option to use multithreading for
+#'  within-chain parallelisation in \code{Stan}. We recommend its use only if
+#'  you are experienced with \code{Stan}'s `reduce_sum` function and have a
+#'  slow running model that cannot be sped up by any other means. Currently
+#'  works for all families when using \pkg{cmdstanr} as the backend
+#'
+#'@param priors An optional \code{data.frame} with prior definitions (in Stan
+#'  syntax) or, preferentially, a vector containing objects of class
+#'  `brmsprior` (see. \code{\link[brms]{prior}} for details). See
+#'  [get_mvgam_priors] and for more information on changing default prior
+#'  distributions
+#'
 #'@param ... Other arguments to pass to [mvgam]
+#'
 #'@author Nicholas J Clark
-#'@details Joint Species Distribution Models allow for responses of multiple species to be
-#'learned hierarchically, whereby responses to environmental variables in `formula` can be partially
-#'pooled and any latent, unmodelled residual associations can also be learned. In \pkg{mvgam}, both of
-#'these effects can be modelled with the full power of latent factor Hierarchical GAMs, providing unmatched
-#'flexibility to model full communities of species. When calling [jsdgam], an initial State-Space model using
-#'`trend = 'None'` is set up and then modified to include the latent factors and their linear predictors.
-#'Consequently, you can inspect priors for these models using [get_mvgam_priors] by supplying the relevant
-#'`formula`, `factor_formula`, `data` and `family` arguments and keeping the default `trend = 'None'`.
+#'
+#'@details Joint Species Distribution Models allow for responses of multiple
+#'species to be learned hierarchically, whereby responses to environmental
+#'variables in `formula` can be partially pooled and any latent, unmodelled
+#'residual associations can also be learned. In \pkg{mvgam}, both of these
+#'effects can be modelled with the full power of latent factor Hierarchical
+#'GAMs, providing unmatched flexibility to model full communities of species.
+#'When calling [jsdgam], an initial State-Space model using `trend = 'None'` is
+#'set up and then modified to include the latent factors and their linear
+#'predictors. Consequently, you can inspect priors for these models using
+#'[get_mvgam_priors] by supplying the relevant `formula`, `factor_formula`,
+#'`data` and `family` arguments and keeping the default `trend = 'None'`.
 #'
 #' In a JSDGAM, the expectation of response \eqn{Y_{ij}} is modelled with
 #'
 #' \deqn{g(\mu_{ij}) = X_i\beta + u_i\theta_j,}
 #'
 #' where \eqn{g(.)} is a known link function,
-#' \eqn{X} is a design matrix of linear predictors (with associated \eqn{\beta} coefficients),
-#' \eqn{u} are \eqn{n_{lv}}-variate latent factors
-#' (\eqn{n_{lv}}<<\eqn{n_{species}}) and
-#' \eqn{\theta_j} are species-specific loadings on the latent factors, respectively. The design matrix
-#' \eqn{X} and \eqn{\beta} coefficients are constructed and modelled using `formula` and can contain
-#' any of `mvgam`'s predictor effects, including random intercepts and slopes, multidimensional penalized
-#' smooths, GP effects etc... The factor loadings \eqn{\theta_j} are constrained for identifiability but can
-#' be used to reconstruct an estimate of the species' residual variance-covariance matrix
-#' using \eqn{\Theta \Theta'} (see the example below and [residual_cor()] for details).
-#' The latent factors are further modelled using:
+#' \eqn{X} is a design matrix of linear predictors (with associated \eqn{\beta}
+#' coefficients), \eqn{u} are \eqn{n_{lv}}-variate latent factors
+#' (\eqn{n_{lv}}<<\eqn{n_{species}}) and \eqn{\theta_j} are species-specific
+#' loadings on the latent factors, respectively. The design matrix \eqn{X} and
+#' \eqn{\beta} coefficients are constructed and modelled using `formula` and
+#' can contain any of `mvgam`'s predictor effects, including random intercepts
+#' and slopes, multidimensional penalized smooths, GP effects etc... The factor
+#' loadings \eqn{\theta_j} are constrained for identifiability but can be used
+#' to reconstruct an estimate of the species' residual variance-covariance
+#' matrix using \eqn{\Theta \Theta'} (see the example below and
+#' [residual_cor()] for details). The latent factors are further modelled using:
 #'\deqn{
-#'u_i \sim \text{Normal}(Q_i\beta_{factor}, 1) \quad
+#'u_i \sim \text{Normal}(Q_i\beta_{factor}, 1)
 #'}
-#'where the second design matrix \eqn{Q} and associated \eqn{\beta_{factor}} coefficients are
-#'constructed and modelled using `factor_formula`. Again, the effects that make up this linear
-#'predictor can contain any of `mvgam`'s allowed predictor effects, providing enormous flexibility for
-#'modelling species' communities.
+#'where the second design matrix \eqn{Q} and associated \eqn{\beta_{factor}}
+#'coefficients are constructed and modelled using `factor_formula`. Again, the
+#'effects that make up this linear predictor can contain any of `mvgam`'s
+#'allowed predictor effects, providing enormous flexibility for modelling
+#'species' communities.
+#'
 #'@seealso [mvgam()], [residual_cor()]
-#'@references Nicholas J Clark & Konstans Wells (2023). Dynamic generalised additive models (DGAMs) for forecasting discrete ecological time series.
+#'
+#'@references Nicholas J Clark & Konstans Wells (2023). Dynamic generalised
+#'additive models (DGAMs) for forecasting discrete ecological time series.
 #'Methods in Ecology and Evolution. 14:3, 771-784.
 #' \cr
 #' \cr
-#'David I Warton, F Guillaume Blanchet, Robert B O’Hara, Otso Ovaskainen, Sara Taskinen, Steven C
-#'Walker & Francis KC Hui (2015). So many variables: joint modeling in community ecology.
-#'Trends in Ecology & Evolution 30:12, 766-779.
+#'David I Warton, F Guillaume Blanchet, Robert B O'Hara, Otso Ovaskainen, Sara
+#'Taskinen, Steven C Walker & Francis KC Hui (2015). So many variables: joint
+#'modeling in community ecology. Trends in Ecology & Evolution 30:12, 766-779.
+#'
 #'@return A \code{list} object of class \code{mvgam} containing model output,
-#'the text representation of the model file,
-#'the mgcv model output (for easily generating simulations at
-#'unsampled covariate values), Dunn-Smyth residuals for each species and key information needed
-#'for other functions in the package. See \code{\link{mvgam-class}} for details.
-#'Use `methods(class = "mvgam")` for an overview on available methods
+#'the text representation of the model file, the mgcv model output (for easily
+#'generating simulations at unsampled covariate values), Dunn-Smyth residuals
+#'for each species and key information needed for other functions in the
+#'package. See \code{\link{mvgam-class}} for details. Use
+#'`methods(class = "mvgam")` for an overview on available methods
+#'
 #'@examples
 #'\donttest{
+#' # ========================================================================
+#' # Example 1: Basic JSDGAM with Portal Data
+#' # ========================================================================
+#'
+#' # Fit a JSDGAM to the portal_data captures
+#' mod <- jsdgam(
+#'   formula = captures ~
+#'     # Fixed effects of NDVI and mintemp, row effect as a GP of time
+#'     ndvi_ma12:series + mintemp:series + gp(time, k = 15),
+#'   factor_formula = ~ -1,
+#'   data = portal_data,
+#'   unit = time,
+#'   species = series,
+#'   family = poisson(),
+#'   n_lv = 2,
+#'   silent = 2,
+#'   chains = 2
+#' )
+#'
+#' # Plot covariate effects
+#' library(ggplot2); theme_set(theme_bw())
+#' plot_predictions(
+#'   mod,
+#'   condition = c('ndvi_ma12', 'series', 'series')
+#' )
+#'
+#' plot_predictions(
+#'   mod,
+#'   condition = c('mintemp', 'series', 'series')
+#' )
+#'
+#' # A residual correlation plot
+#' plot(residual_cor(mod))
+#'
+#' # An ordination biplot can also be constructed
+#' # from the factor scores and their loadings
+#' if(requireNamespace('ggrepel', quietly = TRUE)){
+#'   ordinate(mod, alpha = 0.7)
+#' }
+#'
+#' # ========================================================================
+#' # Example 2: Advanced JSDGAM with Spatial Predictors
+#' # ========================================================================
+#'
 #' # Simulate latent count data for 500 spatial locations and 10 species
 #' set.seed(0)
 #' N_points <- 500
@@ -123,9 +195,11 @@
 #' lat <- runif(N_points, min = -20, max = -19)
 #'
 #' # Set up spatial basis functions as a tensor product of lat and lon
-#' sm <- mgcv::smoothCon(mgcv::te(lon, lat, k = 5),
-#'                       data = data.frame(lon, lat),
-#'                       knots = NULL)[[1]]
+#' sm <- mgcv::smoothCon(
+#'   mgcv::te(lon, lat, k = 5),
+#'   data = data.frame(lon, lat),
+#'   knots = NULL
+#' )[[1]]
 #'
 #' # The design matrix for this smooth is in the 'X' slot
 #' des_mat <- sm$X
@@ -159,38 +233,43 @@
 #' base_field <- mgcv::rmvn(1, mu = rep(0, NCOL(Sigma)), V = Sigma)
 #' for(t in 1:N_species){
 #'   corOmega <- (cov2cor(Sigma) * 0.7) +
-#'                  (0.3 * cov2cor(random_Sigma(N = NCOL(des_mat))))
+#'     (0.3 * cov2cor(random_Sigma(N = NCOL(des_mat))))
 #'   basis_coefs[t, ] <- mgcv::rmvn(1, mu = rep(0, NCOL(Sigma)), V = corOmega)
 #' }
 #'
 #' # Simulate the latent spatial processes
 #' st_process <- do.call(rbind, lapply(seq_len(N_species), function(t){
-#'   data.frame(lat = lat,
-#'              lon = lon,
-#'              species = paste0('species_', t),
-#'              temperature = temperature,
-#'              process = alphas[t] +
-#'                betas[t] * temperature +
-#'                des_mat %*% basis_coefs[t,])
+#'   data.frame(
+#'     lat = lat,
+#'     lon = lon,
+#'     species = paste0('species_', t),
+#'     temperature = temperature,
+#'     process = alphas[t] +
+#'       betas[t] * temperature +
+#'       des_mat %*% basis_coefs[t,]
+#'   )
 #' }))
 #'
 #' # Now take noisy observations at some of the points (60)
 #' obs_points <- sample(1:N_points, size = 60, replace = FALSE)
-#' obs_points <- data.frame(lat = lat[obs_points],
-#'                          lon = lon[obs_points],
-#'                          site = 1:60)
+#' obs_points <- data.frame(
+#'   lat = lat[obs_points],
+#'   lon = lon[obs_points],
+#'   site = 1:60
+#' )
 #'
 #' # Keep only the process data at these points
 #' st_process %>%
 #'   dplyr::inner_join(obs_points, by = c('lat', 'lon')) %>%
 #'   # now take noisy Poisson observations of the process
 #'   dplyr::mutate(count = rpois(NROW(.), lambda = exp(process))) %>%
-#'   dplyr::mutate(species = factor(species,
-#'                                  levels = paste0('species_', 1:N_species))) %>%
+#'   dplyr::mutate(species = factor(
+#'     species,
+#'     levels = paste0('species_', 1:N_species)
+#'   )) %>%
 #'   dplyr::group_by(lat, lon) -> dat
 #'
 #' # View the count distributions for each species
-#' library(ggplot2); theme_set(theme_bw())
 #' ggplot(dat, aes(x = count)) +
 #'   geom_histogram() +
 #'   facet_wrap(~ species, scales = 'free')
@@ -200,66 +279,78 @@
 #'   facet_wrap(~ species, scales = 'free') +
 #'   scale_color_viridis_c()
 #'
+#' # ------------------------------------------------------------------------
+#' # Model Fitting with Custom Priors
+#' # ------------------------------------------------------------------------
+#'
 #' # Inspect default priors for a joint species model with three spatial factors
-#' priors <- get_mvgam_priors(formula = count ~
-#'                             # Environmental model includes random slopes for
-#'                             # a linear effect of temperature
-#'                             s(species, bs = 're', by = temperature),
+#' priors <- get_mvgam_priors(
+#'   formula = count ~
+#'     # Environmental model includes random slopes for
+#'     # a linear effect of temperature
+#'     s(species, bs = 're', by = temperature),
 #'
-#'                           # Each factor estimates a different nonlinear spatial process, using
-#'                           # 'by = trend' as in other mvgam State-Space models
-#'                           factor_formula = ~ gp(lon, lat, k = 6, by = trend) - 1,
-#'                           n_lv = 3,
+#'   # Each factor estimates a different nonlinear spatial process, using
+#'   # 'by = trend' as in other mvgam State-Space models
+#'   factor_formula = ~ gp(lon, lat, k = 6, by = trend) - 1,
+#'   n_lv = 3,
 #'
-#'                           # The data and grouping variables
-#'                           data = dat,
-#'                           unit = site,
-#'                           species = species,
+#'   # The data and grouping variables
+#'   data = dat,
+#'   unit = site,
+#'   species = species,
 #'
-#'                           # Poisson observations
-#'                           family = poisson())
+#'   # Poisson observations
+#'   family = poisson()
+#' )
 #' head(priors)
 #'
 #' # Fit a JSDM that estimates hierarchical temperature responses
 #' # and that uses three latent spatial factors
-#' mod <- jsdgam(formula = count ~
-#'                 # Environmental model includes random slopes for a
-#'                 # linear effect of temperature
-#'                 s(species, bs = 're', by = temperature),
+#' mod <- jsdgam(
+#'   formula = count ~
+#'     # Environmental model includes random slopes for a
+#'     # linear effect of temperature
+#'     s(species, bs = 're', by = temperature),
 #'
-#'               # Each factor estimates a different nonlinear spatial process, using
-#'               # 'by = trend' as in other mvgam State-Space models
-#'               factor_formula = ~ gp(lon, lat, k = 6, by = trend) - 1,
-#'               n_lv = 3,
+#'   # Each factor estimates a different nonlinear spatial process, using
+#'   # 'by = trend' as in other mvgam State-Space models
+#'   factor_formula = ~ gp(lon, lat, k = 6, by = trend) - 1,
+#'   n_lv = 3,
 #'
-#'               # Change default priors for fixed random effect variances and
-#'               # factor P marginal deviations to standard normal
-#'               priors = c(prior(std_normal(),
-#'                                class = sigma_raw),
-#'                          prior(std_normal(),
-#'                                class = `alpha_gp_trend(lon, lat):trendtrend1`),
-#'                          prior(std_normal(),
-#'                                class = `alpha_gp_trend(lon, lat):trendtrend2`),
-#'                          prior(std_normal(),
-#'                                class = `alpha_gp_trend(lon, lat):trendtrend3`)),
+#'   # Change default priors for fixed random effect variances and
+#'   # factor GP marginal deviations to standard normal
+#'   priors = c(
+#'     prior(std_normal(), class = sigma_raw),
+#'     prior(std_normal(), class = `alpha_gp_trend(lon, lat):trendtrend1`),
+#'     prior(std_normal(), class = `alpha_gp_trend(lon, lat):trendtrend2`),
+#'     prior(std_normal(), class = `alpha_gp_trend(lon, lat):trendtrend3`)
+#'   ),
 #'
-#'               # The data and the grouping variables
-#'               data = dat,
-#'               unit = site,
-#'               species = species,
+#'   # The data and the grouping variables
+#'   data = dat,
+#'   unit = site,
+#'   species = species,
 #'
-#'               # Poisson observations
-#'               family = poisson(),
-#'               chains = 2,
-#'               silent = 2)
+#'   # Poisson observations
+#'   family = poisson(),
+#'   chains = 2,
+#'   silent = 2
+#' )
 #'
-#' # Plot species-level intercept estimates
-#' plot_predictions(mod, condition = 'species',
-#'                  type = 'link')
+#' # ------------------------------------------------------------------------
+#' # Model Visualization and Diagnostics
+#' # ------------------------------------------------------------------------
+#'
+#' # Plot the implicit species-level intercept estimates
+#' plot_predictions(mod, condition = 'species', type = 'link')
 #'
 #' # Plot species' hierarchical responses to temperature
-#' plot_predictions(mod, condition = c('temperature', 'species', 'species'),
-#'                  type = 'link')
+#' plot_predictions(
+#'   mod,
+#'   condition = c('temperature', 'species', 'species'),
+#'   type = 'link'
+#' )
 #'
 #' # Plot posterior median estimates of the latent spatial factors
 #' plot(mod, type = 'smooths', trend_effects = TRUE)
@@ -271,31 +362,49 @@
 #'
 #' # Plot species' randomized quantile residual distributions
 #' # as a function of latitude
-#' pp_check(mod,
-#'          type = 'resid_ribbon_grouped',
-#'          group = 'species',
-#'          x = 'lat',
-#'          ndraws = 200)
+#' pp_check(
+#'   mod,
+#'   type = 'resid_ribbon_grouped',
+#'   group = 'species',
+#'   x = 'lat',
+#'   ndraws = 200
+#' )
+#'
+#' # ------------------------------------------------------------------------
+#' # Residual Correlation Analysis
+#' # ------------------------------------------------------------------------
 #'
 #' # Calculate residual spatial correlations
 #' post_cors <- residual_cor(mod)
 #' names(post_cors)
-
+#'
 #' # Look at lower and upper credible interval estimates for
 #' # some of the estimated correlations
 #' post_cors$cor[1:5, 1:5]
 #' post_cors$cor_upper[1:5, 1:5]
 #' post_cors$cor_lower[1:5, 1:5]
-
+#'
 #' # Plot of the posterior median correlations for those estimated
 #' # to be non-zero
-#' plot(post_cors)
+#' plot(post_cors, cluster = TRUE)
+#'
+#' # An ordination biplot can also be constructed
+#' # from the factor scores and their loadings
+#' if(requireNamespace('ggrepel', quietly = TRUE)){
+#'   ordinate(mod)
+#' }
+#'
+#' # ------------------------------------------------------------------------
+#' # Model Validation and Prediction
+#' # ------------------------------------------------------------------------
 #'
 #' # Posterior predictive checks and ELPD-LOO can ascertain model fit
-#' pp_check(mod,
-#'          type = "pit_ecdf_grouped",
-#'          group = "species",
-#'          ndraws = 200)
+#' pp_check(
+#'   mod,
+#'   type = "pit_ecdf_grouped",
+#'   group = "species",
+#'   ndraws = 200
+#' )
 #' loo(mod)
 #'
 #' # Forecast log(counts) for entire region (site value doesn't matter as long
@@ -303,12 +412,13 @@
 #' # note this calculation takes a few minutes because of the need to calculate
 #' # draws from the stochastic latent factors
 #' newdata <- st_process %>%
-#'                    dplyr::mutate(species = factor(species,
-#'                                                   levels = paste0('species_',
-#'                                                                   1:N_species))) %>%
-#'                    dplyr::group_by(lat, lon) %>%
-#'                    dplyr::mutate(site = dplyr::cur_group_id()) %>%
-#'                    dplyr::ungroup()
+#'   dplyr::mutate(species = factor(
+#'     species,
+#'     levels = paste0('species_', 1:N_species)
+#'   )) %>%
+#'   dplyr::group_by(lat, lon) %>%
+#'   dplyr::mutate(site = dplyr::cur_group_id()) %>%
+#'   dplyr::ungroup()
 #' preds <- predict(mod, newdata = newdata)
 #'
 #' # Plot the median log(count) predictions on a grid
@@ -318,6 +428,11 @@
 #'   facet_wrap(~ species, scales = 'free') +
 #'   scale_color_viridis_c() +
 #'   theme_classic()
+#'
+#' \dontshow{
+#' # For R CMD check: make sure any open connections are closed afterward
+#'   closeAllConnections()
+#' }
 #'}
 #'@export
 jsdgam = function(
@@ -366,7 +481,7 @@ jsdgam = function(
 
   # Set up the model structure but leave autoformat off so that the
   # model file can be easily modified
-  mod <- mvgam(
+  mod <- suppressWarnings(mvgam(
     formula = formula,
     trend_formula = factor_formula,
     knots = knots,
@@ -382,7 +497,7 @@ jsdgam = function(
     autoformat = FALSE,
     backend = backend,
     ...
-  )
+  ))
   model_file <- mod$model_file
 
   #### Modify model data and model file ####
@@ -451,31 +566,61 @@ jsdgam = function(
   )
   ends <- starts + 5
   model_file <- model_file[-(starts:ends)]
-  model_file[grep(
-    "// latent process linear predictors",
-    model_file,
-    fixed = TRUE
-  )] <- paste0(
-    "// latent process linear predictors\n",
-    "trend_mus = X_trend * b_trend;\n\n",
-    "// constraints allow identifiability of loadings\n",
-    "{\n",
-    "int idx;\n",
-    "idx = 0;\n",
-    "for(j in 1 : n_lv) lv_coefs[j, j] = L_diag[j];\n",
-    "for(j in 1 : n_lv) {\n",
-    "for(k in (j + 1) : n_series) {\n",
-    "idx = idx + 1;\n",
-    "lv_coefs[k, j] = L_lower[idx];\n",
-    "}\n",
-    "}\n",
-    "}\n\n",
-    "// raw latent factors (with linear predictors)\n",
-    "for (j in 1 : n_lv) {\n",
-    "for (i in 1 : n) {\n",
-    "LV[i, j] = trend_mus[ytimes_trend[i, j]] + LV_raw[i, j];\n",
-    "}\n}\n"
-  )
+
+  # Simplified latent variable creation if no terms in factor_formula
+  if (
+    is.null(rownames(attr(terms.formula(factor_formula), 'factors'))) &
+      is.null(colnames(attr(terms.formula(factor_formula), 'factors')))
+  ) {
+    model_file[grep(
+      "// latent process linear predictors",
+      model_file,
+      fixed = TRUE
+    )] <- paste0(
+      "// latent process linear predictors\n",
+      "trend_mus = X_trend * b_trend;\n\n",
+      "// constraints allow identifiability of loadings\n",
+      "{\n",
+      "int idx;\n",
+      "idx = 0;\n",
+      "for(j in 1 : n_lv) lv_coefs[j, j] = L_diag[j];\n",
+      "for(j in 1 : n_lv) {\n",
+      "for(k in (j + 1) : n_series) {\n",
+      "idx = idx + 1;\n",
+      "lv_coefs[k, j] = L_lower[idx];\n",
+      "}\n",
+      "}\n",
+      "}\n\n",
+      "// raw latent factors\n",
+      "LV = LV_raw;\n"
+    )
+  } else {
+    model_file[grep(
+      "// latent process linear predictors",
+      model_file,
+      fixed = TRUE
+    )] <- paste0(
+      "// latent process linear predictors\n",
+      "trend_mus = X_trend * b_trend;\n\n",
+      "// constraints allow identifiability of loadings\n",
+      "{\n",
+      "int idx;\n",
+      "idx = 0;\n",
+      "for(j in 1 : n_lv) lv_coefs[j, j] = L_diag[j];\n",
+      "for(j in 1 : n_lv) {\n",
+      "for(k in (j + 1) : n_series) {\n",
+      "idx = idx + 1;\n",
+      "lv_coefs[k, j] = L_lower[idx];\n",
+      "}\n",
+      "}\n",
+      "}\n\n",
+      "// raw latent factors (with linear predictors)\n",
+      "for (j in 1 : n_lv) {\n",
+      "for (i in 1 : n) {\n",
+      "LV[i, j] = trend_mus[ytimes_trend[i, j]] + LV_raw[i, j];\n",
+      "}\n}\n"
+    )
+  }
 
   model_file <- model_file[
     -grep("// derived latent states", model_file, fixed = TRUE)
@@ -490,16 +635,32 @@ jsdgam = function(
   ) +
     1
   model_file <- model_file[-sigma_prior]
-  model_file[grep(
-    "// priors for latent state SD parameters",
-    model_file,
-    fixed = TRUE
-  )] <- paste0(
-    "// priors for factors and loading coefficients\n",
-    "L_lower ~ student_t(3, 0, 1);\n",
-    "L_diag ~ student_t(3, 0, 1);"
-  )
-  model_file <- readLines(textConnection(model_file), n = -1)
+
+  # Use standard normal for loadings in most models, apart from
+  # those using identify link
+  if (family_links(mod$family) != 'identity') {
+    model_file[grep(
+      "// priors for latent state SD parameters",
+      model_file,
+      fixed = TRUE
+    )] <- paste0(
+      "// priors for factors and loading coefficients\n",
+      "L_lower ~ std_normal();\n",
+      "L_diag ~ std_normal();"
+    )
+    model_file <- readLines(textConnection(model_file), n = -1)
+  } else {
+    model_file[grep(
+      "// priors for latent state SD parameters",
+      model_file,
+      fixed = TRUE
+    )] <- paste0(
+      "// priors for factors and loading coefficients\n",
+      "L_lower ~ student_t(3, 0, 1);\n",
+      "L_diag ~ student_t(3, 0, 1);"
+    )
+    model_file <- readLines(textConnection(model_file), n = -1)
+  }
 
   # Update generated quantities
   model_file[grep(
