@@ -52,7 +52,9 @@ noncent_trend = function(model_file, trend_model, drift) {
         "vector[num_basis] b;\n\n",
         "// latent trends\n",
         "matrix[n, n_series] trend;\n",
-        "trend = trend_raw .* rep_matrix(sigma', rows(trend_raw));\n",
+        "trend = trend_raw .* rep_matrix(sigma', n) .*",
+        "(1 - rep_matrix(ar1', n) .^ (2 * to_matrix(time_dis))) ./",
+        "(1 - rep_matrix(ar1', n) .^ 2);\n",
         "for (s in 1 : n_series) {\n",
         "trend[2 : n, s] +=",
         drift_text,
