@@ -1,62 +1,110 @@
-#'Plot posterior forecast predictions from \pkg{mvgam} models
-#'@importFrom stats formula terms
-#'@param object \code{list} object of class \code{mvgam}. See [mvgam()]
-#'@param series \code{integer} specifying which series in the set is to be plotted
-#'@param newdata Optional \code{dataframe} or \code{list} of test data containing at least 'series' and 'time'
-#'in addition to any other variables included in the linear predictor of the original \code{formula}. If included, the
-#'covariate information in \code{newdata} will be used to generate forecasts from the fitted model equations. If
-#'this same \code{newdata} was originally included in the call to \code{mvgam}, then forecasts have already been
-#'produced by the generative model and these will simply be extracted and plotted. However if no \code{newdata} was
-#'supplied to the original model call, an assumption is made that the \code{newdata} supplied here comes sequentially
-#'after the data supplied as \code{data} in the original model (i.e. we assume there is no time gap between the last
-#'observation of series 1 in \code{data} and the first observation for series 1 in \code{newdata}). If
-#'\code{newdata} contains observations in column \code{y}, these observations will be used to compute a Discrete Rank
-#'Probability Score for the forecast distribution
-#'@param data_test Deprecated. Still works in place of \code{newdata} but users are recommended to use
-#'\code{newdata} instead for more seamless integration into `R` workflows
-#'@param realisations \code{logical}. If \code{TRUE}, forecast realisations are shown as a spaghetti plot,
-#'making it easier to visualise the diversity of possible forecasts. If \code{FALSE}, the default,
-#'empirical quantiles of the forecast distribution are shown
-#'@param n_realisations \code{integer} specifying the number of posterior realisations to plot, if
-#'\code{realisations = TRUE}. Ignored otherwise
-#'@param n_cores \code{integer} specifying number of cores for generating forecasts in parallel
-#'@param hide_xlabels \code{logical}. If \code{TRUE}, no xlabels are printed to allow the user to add custom labels using
-#'\code{axis} from base \code{R}
-#'@param xlab label for x axis.
-#'@param ylab label for y axis.
-#'@param ylim Optional \code{vector} of y-axis limits (min, max)
-#'@param ... further \code{\link[graphics]{par}} graphical parameters.
-#'@param return_forecasts \code{logical}. If \code{TRUE}, the function will plot the forecast
-#'as well as returning the forecast object (as a \code{matrix} of dimension \code{n_samples} x \code{horizon})
-#'@param return_score \code{logical}. If \code{TRUE} and out of sample test data is provided as
-#'\code{newdata}, a probabilistic score will be calculated and returned. The score used will depend on the
-#'observation family from the fitted model. Discrete families (\code{poisson}, \code{negative binomial}, \code{tweedie})
-#'use the Discrete Rank Probability Score. Other families use the Continuous Rank Probability Score. The value
-#'returned is the \code{sum} of all scores within the out of sample forecast horizon
-#'@details `plot_mvgam_fc` generates posterior predictions from an object of class \code{mvgam}, calculates posterior
-#' empirical quantiles and plots them against the observed data. If `realisations = FALSE`, the returned plot shows
-#' 90, 60, 40 and 20 percent posterior quantiles (as ribbons of increasingly darker shades or red)
-#' as well as the posterior median (as a dark red line). If `realisations = FALSE`, a set of `n_realisations` posterior
-#' draws are shown. This function produces an older style base \code{R} plot, as opposed to `plot.mvgam_forecast`
+#' Plot posterior forecast predictions from \pkg{mvgam} models
 #'
-#'`plot.mvgam_forecast` takes an object of class `mvgam_forecast`, in which forecasts have already
-#'been computed, and plots the resulting forecast distribution as a `ggplot` object. This function is therefore more
-#'versatile and is recommended over the older and clunkier `plot_mvgam_fc` version
+#' @importFrom stats formula terms
+#'
+#' @param object \code{list} object of class \code{mvgam}. See [mvgam()]
+#'
+#' @param series \code{integer} specifying which series in the set is to be
+#'   plotted
+#'
+#' @param newdata Optional \code{dataframe} or \code{list} of test data
+#'   containing at least 'series' and 'time' in addition to any other
+#'   variables included in the linear predictor of the original
+#'   \code{formula}. If included, the covariate information in \code{newdata}
+#'   will be used to generate forecasts from the fitted model equations. If
+#'   this same \code{newdata} was originally included in the call to
+#'   \code{mvgam}, then forecasts have already been produced by the generative
+#'   model and these will simply be extracted and plotted. However if no
+#'   \code{newdata} was supplied to the original model call, an assumption is
+#'   made that the \code{newdata} supplied here comes sequentially after the
+#'   data supplied as \code{data} in the original model (i.e. we assume there
+#'   is no time gap between the last observation of series 1 in \code{data}
+#'   and the first observation for series 1 in \code{newdata}). If
+#'   \code{newdata} contains observations in column \code{y}, these
+#'   observations will be used to compute a Discrete Rank Probability Score
+#'   for the forecast distribution
+#'
+#' @param data_test Deprecated. Still works in place of \code{newdata} but
+#'   users are recommended to use \code{newdata} instead for more seamless
+#'   integration into `R` workflows
+#'
+#' @param realisations \code{logical}. If \code{TRUE}, forecast realisations
+#'   are shown as a spaghetti plot, making it easier to visualise the
+#'   diversity of possible forecasts. If \code{FALSE}, the default, empirical
+#'   quantiles of the forecast distribution are shown
+#'
+#' @param n_realisations \code{integer} specifying the number of posterior
+#'   realisations to plot, if \code{realisations = TRUE}. Ignored otherwise
+#'
+#' @param n_cores \code{integer} specifying number of cores for generating
+#'   forecasts in parallel
+#'
+#' @param hide_xlabels \code{logical}. If \code{TRUE}, no xlabels are printed
+#'   to allow the user to add custom labels using \code{axis} from base
+#'   \code{R}
+#'
+#' @param xlab Label for x axis
+#'
+#' @param ylab Label for y axis
+#'
+#' @param ylim Optional \code{vector} of y-axis limits (min, max)
+#'
+#' @param ... Further \code{\link[graphics]{par}} graphical parameters
+#'
+#' @param return_forecasts \code{logical}. If \code{TRUE}, the function will
+#'   plot the forecast as well as returning the forecast object (as a
+#'   \code{matrix} of dimension \code{n_samples} x \code{horizon})
+#'
+#' @param return_score \code{logical}. If \code{TRUE} and out of sample test
+#'   data is provided as \code{newdata}, a probabilistic score will be
+#'   calculated and returned. The score used will depend on the observation
+#'   family from the fitted model. Discrete families (\code{poisson},
+#'   \code{negative binomial}, \code{tweedie}) use the Discrete Rank
+#'   Probability Score. Other families use the Continuous Rank Probability
+#'   Score. The value returned is the \code{sum} of all scores within the out
+#'   of sample forecast horizon
+#'
+#' @author Nicholas J Clark
+#'
+#' @details `plot_mvgam_fc` generates posterior predictions from an object of
+#'   class \code{mvgam}, calculates posterior empirical quantiles and plots
+#'   them against the observed data. If `realisations = FALSE`, the returned
+#'   plot shows 90, 60, 40 and 20 percent posterior quantiles (as ribbons of
+#'   increasingly darker shades of red) as well as the posterior median (as a
+#'   dark red line). If `realisations = TRUE`, a set of `n_realisations`
+#'   posterior draws are shown. This function produces an older style base
+#'   \code{R} plot, as opposed to `plot.mvgam_forecast`
+#'
+#'   `plot.mvgam_forecast` takes an object of class `mvgam_forecast`, in which
+#'   forecasts have already been computed, and plots the resulting forecast
+#'   distribution as a `ggplot` object. This function is therefore more
+#'   versatile and is recommended over the older and clunkier
+#'   `plot_mvgam_fc` version
+#'
+#'   If \code{realisations = FALSE}, these posterior quantiles are plotted
+#'   along with the true observed data that was used to train the model.
+#'   Otherwise, a spaghetti plot is returned to show possible forecast paths.
+#'
+#' @return A base \code{R} graphics plot (for `plot_mvgam_fc`) or a `ggplot`
+#'   object (for `plot.mvgam_forecast`) and an optional \code{list} containing
+#'   the forecast distribution and the out of sample probabilistic forecast
+#'   score
 #'
-#'If \code{realisations = FALSE}, these posterior quantiles are plotted along
-#'with the true observed data that was used to train the model. Otherwise, a spaghetti plot is returned
-#'to show possible forecast paths.
-#'@return A base \code{R} graphics plot (for `plot_mvgam_fc`) or a `ggplot` object (for `plot.mvgam_forecast`) and an optional \code{list} containing the forecast distribution
-#'and the out of sample probabilistic forecast score
 #' @examples
 #' \donttest{
-#' simdat <- sim_mvgam(n_series = 3, trend_model = AR())
-#' mod <- mvgam(y ~ s(season, bs = 'cc', k = 6),
-#'             trend_model = AR(),
-#'             noncentred = TRUE,
-#'             data = simdat$data_train,
-#'             chains = 2,
-#'             silent = 2)
+#' simdat <- sim_mvgam(
+#'   n_series = 3,
+#'   trend_model = AR()
+#' )
+#'
+#' mod <- mvgam(
+#'   y ~ s(season, bs = 'cc', k = 6),
+#'   trend_model = AR(),
+#'   noncentred = TRUE,
+#'   data = simdat$data_train,
+#'   chains = 2,
+#'   silent = 2
+#' )
 #'
 #' # Hindcasts on response scale
 #' hc <- hindcast(mod)
@@ -66,24 +114,36 @@
 #' plot(hc, series = 3)
 #'
 #' # Forecasts on response scale
-#' fc <- forecast(mod, newdata = simdat$data_test)
+#' fc <- forecast(
+#'   mod,
+#'   newdata = simdat$data_test
+#' )
 #' str(fc)
 #' plot(fc, series = 1)
 #' plot(fc, series = 2)
 #' plot(fc, series = 3)
 #'
 #' # Forecasts as expectations
-#' fc <- forecast(mod, newdata = simdat$data_test, type = 'expected')
+#' fc <- forecast(
+#'   mod,
+#'   newdata = simdat$data_test,
+#'   type = 'expected'
+#' )
 #' plot(fc, series = 1)
 #' plot(fc, series = 2)
 #' plot(fc, series = 3)
 #'
 #' # Dynamic trend extrapolations
-#' fc <- forecast(mod, newdata = simdat$data_test, type = 'trend')
+#' fc <- forecast(
+#'   mod,
+#'   newdata = simdat$data_test,
+#'   type = 'trend'
+#' )
 #' plot(fc, series = 1)
 #' plot(fc, series = 2)
 #' plot(fc, series = 3)
 #' }
+#'
 #' @name plot_mvgam_forecasts
 NULL
 
@@ -642,8 +702,11 @@ plot_mvgam_fc = function(
 }
 
 #' @rdname plot_mvgam_forecasts
+#'
 #' @param x Object of class `mvgam_forecast`
+#'
 #' @method plot mvgam_forecast
+#'
 #' @export
 plot.mvgam_forecast = function(
   x,
@@ -736,7 +799,10 @@ plot.mvgam_forecast = function(
   # Create a base plot using posterior credible intervals and observations
   # for the specified series
   plot_dat <- data.frame(
-    time = c(object$train_times, object$test_times),
+    time = c(
+      object$train_times[[which(names(object$hindcasts) == s_name)]],
+      object$test_times[[which(names(object$hindcasts) == s_name)]]
+    ),
     med = cred[5, ],
     lower1 = cred[1, ],
     lower2 = cred[2, ],
@@ -766,7 +832,10 @@ plot.mvgam_forecast = function(
         ggplot2::geom_line(
           data = data.frame(
             y = preds[i, ],
-            time = c(object$train_times, object$test_times)
+            time = c(
+              object$train_times[[which(names(object$hindcasts) == s_name)]],
+              object$test_times[[which(names(object$hindcasts) == s_name)]]
+            )
           ),
           mapping = ggplot2::aes(x = time, y = y),
           col = "white",
@@ -775,7 +844,10 @@ plot.mvgam_forecast = function(
         ggplot2::geom_line(
           data = data.frame(
             y = preds[i, ],
-            time = c(object$train_times, object$test_times)
+            time = c(
+              object$train_times[[which(names(object$hindcasts) == s_name)]],
+              object$test_times[[which(names(object$hindcasts) == s_name)]]
+            )
           ),
           mapping = ggplot2::aes(x = time, y = y),
           col = sample(
@@ -812,13 +884,14 @@ plot.mvgam_forecast = function(
 
   # Show historical (hindcast) distribution in grey if this object
   # contains forecasts
+  train_times <- object$train_times[[s_name]]
   last_train <- length(object$train_observations[[s_name]])
   if (type == 'response' & !is.null(object$forecasts)) {
     if (!realisations) {
       base_plot <- base_plot +
         ggplot2::geom_line(
           data = data.frame(
-            time = 1:last_train,
+            time = train_times,
             lower1 = cred[1, 1:last_train],
             upper1 = cred[9, 1:last_train],
             med = cred[5, 1:last_train],
@@ -830,7 +903,7 @@ plot.mvgam_forecast = function(
         ) +
         ggplot2::geom_ribbon(
           data = data.frame(
-            time = 1:last_train,
+            time = train_times,
             lower1 = cred[1, 1:last_train],
             upper1 = cred[9, 1:last_train],
             truth = 0
@@ -848,8 +921,15 @@ plot.mvgam_forecast = function(
     base_plot <- base_plot +
       ggplot2::geom_point(pch = 21, col = 'white', fill = 'black')
 
-    # Calculate out of sample probabilistic score
-    fc <- object$forecasts[[s_name]]
+    # Calculate out of sample probabilistic score;
+    # need to ensure fc is a matrix, even if only a single
+    # out of sample observation was forecasted (#111)
+    if (!is.null(object$forecasts)) {
+      fc <- as.matrix(object$forecasts[[s_name]])
+    } else {
+      fc <- NULL
+    }
+
     truth <- object$test_observations[[s_name]]
 
     if (all(is.na(truth))) {
@@ -893,7 +973,10 @@ plot.mvgam_forecast = function(
 
   if (!is.null(object$forecasts)) {
     base_plot <- base_plot +
-      ggplot2::geom_vline(xintercept = last_train, linetype = 'dashed')
+      ggplot2::geom_vline(
+        xintercept = max(train_times),
+        linetype = 'dashed'
+      )
   }
 
   if (!missing(ylim)) {
