@@ -1,58 +1,94 @@
 #' @title Plot conditional posterior predictive checks from \pkg{mvgam} models
+#'
 #' @importFrom stats quantile density ecdf formula terms
 #' @importFrom graphics hist abline box rect lines polygon par
 #' @importFrom grDevices rgb
+#'
 #' @name ppc.mvgam
+#'
 #' @param object \code{list} object returned from \code{mvgam}. See [mvgam()]
-#' @param newdata Optional \code{dataframe} or \code{list} of test data containing at least 'series' and 'time'
-#' for the forecast horizon, in addition to any other variables included in the linear predictor of \code{formula}. If
-#' included, the observed values in the test data are compared to the model's forecast distribution for exploring
-#' biases in model predictions.
-#' Note this is only useful if the same \code{newdata} was also included when fitting the original model.
-#' @param data_test Deprecated. Still works in place of \code{newdata} but users are recommended to use
-#' \code{newdata} instead for more seamless integration into `R` workflows
-#' @param series \code{integer} specifying which series in the set is to be plotted
-#' @param type \code{character} specifying the type of posterior predictive check to calculate and plot.
-#' Valid options are: 'rootogram', 'mean', 'hist', 'density', 'prop_zero', 'pit' and 'cdf'
-#' @param n_bins \code{integer} specifying the number of bins to use for binning observed values when plotting
-#' a rootogram or histogram. Default is `50` bins for a rootogram, which means that if
-#' there are `>50` unique observed values, bins will
-#' be used to prevent overplotting and facilitate interpretation. Default for a histogram is to use the
-#' number of bins returned by a call to `hist` in base `R`
-#' @param legend_position The location may also be specified by setting x to a single keyword from the
-#' list "bottomright", "bottom", "bottomleft", "left", "topleft", "top", "topright", "right" and "center".
-#' This places the legend on the inside of the plot frame at the given location. Or alternatively,
-#' use "none" to hide the legend.
-#' @param xlab label for x axis.
-#' @param ylab label for y axis.
-#' @param ... further \code{\link[graphics]{par}} graphical parameters.
-#' @details Conditional posterior predictions are drawn from the fitted \code{mvgam} and compared against
-#' the empirical distribution of the observed data for a specified series to help evaluate the model's
-#' ability to generate unbiased predictions. For all plots apart from `type = 'rootogram'`, posterior predictions
-#' can also be compared to out of sample observations as long as these observations were included as
-#'' data_test' in the original model fit and supplied here. Rootograms are currently only plotted using the
-#'' hanging' style.
-#' \cr
-#' Note that the predictions used for these plots are *conditional on the observed data*, i.e. they
-#' are those predictions that have been generated directly within
-#' the `mvgam()` model. They can be misleading if the model included flexible dynamic trend components. For
-#' a broader range of posterior checks that are created using *unconditional* "new data" predictions, see
-#' \code{\link{pp_check.mvgam}}
-#' @return A base \code{R} graphics plot showing either a posterior rootogram (for \code{type == 'rootogram'}),
-#' the predicted vs observed mean for the
-#' series (for \code{type == 'mean'}), predicted vs observed proportion of zeroes for the
-#' series (for \code{type == 'prop_zero'}),predicted vs observed histogram for the
-#' series (for \code{type == 'hist'}), kernel density or empirical CDF estimates for
-#' posterior predictions (for \code{type == 'density'} or \code{type == 'cdf'}) or a Probability
-#' Integral Transform histogram (for \code{type == 'pit'}).
+#'
+#' @param newdata Optional \code{dataframe} or \code{list} of test data
+#'   containing at least 'series' and 'time' for the forecast horizon, in
+#'   addition to any other variables included in the linear predictor of
+#'   \code{formula}. If included, the observed values in the test data are
+#'   compared to the model's forecast distribution for exploring biases in
+#'   model predictions. Note this is only useful if the same \code{newdata}
+#'   was also included when fitting the original model.
+#'
+#' @param data_test Deprecated. Still works in place of \code{newdata} but
+#'   users are recommended to use \code{newdata} instead for more seamless
+#'   integration into `R` workflows
+#'
+#' @param series \code{integer} specifying which series in the set is to be
+#'   plotted
+#'
+#' @param type \code{character} specifying the type of posterior predictive
+#'   check to calculate and plot. Valid options are: 'rootogram', 'mean',
+#'   'hist', 'density', 'prop_zero', 'pit' and 'cdf'
+#'
+#' @param n_bins \code{integer} specifying the number of bins to use for
+#'   binning observed values when plotting a rootogram or histogram. Default
+#'   is `50` bins for a rootogram, which means that if there are >50 unique
+#'   observed values, bins will be used to prevent overplotting and facilitate
+#'   interpretation. Default for a histogram is to use the number of bins
+#'   returned by a call to `hist` in base `R`
+#'
+#' @param legend_position The location may also be specified by setting x to a
+#'   single keyword from the list "bottomright", "bottom", "bottomleft",
+#'   "left", "topleft", "top", "topright", "right" and "center". This places
+#'   the legend on the inside of the plot frame at the given location. Or
+#'   alternatively, use "none" to hide the legend.
+#'
+#' @param xlab Label for x axis
+#'
+#' @param ylab Label for y axis
+#'
+#' @param ... Further \code{\link[graphics]{par}} graphical parameters
+#'
+#' @details Conditional posterior predictions are drawn from the fitted
+#'   \code{mvgam} and compared against the empirical distribution of the
+#'   observed data for a specified series to help evaluate the model's ability
+#'   to generate unbiased predictions. For all plots apart from
+#'   `type = 'rootogram'`, posterior predictions can also be compared to out
+#'   of sample observations as long as these observations were included as
+#'   'data_test' in the original model fit and supplied here. Rootograms are
+#'   currently only plotted using the 'hanging' style.
+#'
+#'   
+#'   Note that the predictions used for these plots are *conditional on
+#'   the observed data*, i.e. they are those predictions that have been
+#'   generated directly within the `mvgam()` model. They can be misleading if
+#'   the model included flexible dynamic trend components. For a broader range
+#'   of posterior checks that are created using *unconditional* "new data"
+#'   predictions, see \code{\link{pp_check.mvgam}}
+#'
+#' @return A base \code{R} graphics plot showing either a posterior rootogram
+#'   (for \code{type == 'rootogram'}), the predicted vs observed mean for the
+#'   series (for \code{type == 'mean'}), predicted vs observed proportion of
+#'   zeroes for the series (for \code{type == 'prop_zero'}), predicted vs
+#'   observed histogram for the series (for \code{type == 'hist'}), kernel
+#'   density or empirical CDF estimates for posterior predictions (for
+#'   \code{type == 'density'} or \code{type == 'cdf'}) or a Probability
+#'   Integral Transform histogram (for \code{type == 'pit'}).
+#'
 #' @author Nicholas J Clark
+#'
 #' @seealso \code{\link{pp_check.mvgam}}, \code{\link{predict.mvgam}}
+#'
 #' @examples
 #' \donttest{
 #' # Simulate some smooth effects and fit a model
 #' set.seed(0)
-#' dat <- mgcv::gamSim(1, n = 200, scale = 2)
-#' mod <- mvgam(y ~ s(x0) + s(x1) + s(x2) + s(x3),
+#'
+#' dat <- mgcv::gamSim(
+#'   1,
+#'   n = 200,
+#'   scale = 2
+#' )
+#'
+#' mod <- mvgam(
+#'   y ~ s(x0) + s(x1) + s(x2) + s(x3),
 #'   data = dat,
 #'   family = gaussian(),
 #'   chains = 2,
@@ -69,7 +105,9 @@
 #' pp_check(mod, type = "ecdf_overlay")
 #' pp_check(mod, type = "freqpoly")
 #' }
+#'
 #' @export
+
 ppc <- function(object, ...) {
   UseMethod("ppc", object)
 }
@@ -102,7 +140,9 @@ ppc.mvgam <- function(
       "prop_zero"
     )
   )
-  if (type == "histogram") type <- "hist"
+  if (type == "histogram") {
+    type <- "hist"
+  }
 
   if (type == "rootogram") {
     if (
@@ -803,8 +843,7 @@ ppc.mvgam <- function(
 
   if (type == "cdf") {
     ecdf_plotdat <- function(vals, x) {
-      if (length(which(is.na(vals))) > (length(vals) - 3)) {
-      } else {
+      if (length(which(is.na(vals))) > (length(vals) - 3)) {} else {
         func <- ecdf(vals)
         func(x)
       }
@@ -944,17 +983,23 @@ ppc.mvgam <- function(
 #' of the \pkg{bayesplot} package.
 #'
 #' @aliases pp_check
+#'
 #' @inheritParams brms::pp_check
+#' @inheritParams brms::prepare_predictions.brmsfit
+#'
 #' @importFrom insight get_predictors
 #' @importFrom brms do_call
-#' @param object An object of class \code{mvgam}.
+#' @importFrom bayesplot pp_check
+#'
+#' @param object An object of class \code{mvgam}
+#'
 #' @param newdata Optional \code{dataframe} or \code{list} of test data containing the
 #' variables included in the linear predictor of \code{formula}. If not supplied,
 #' predictions are generated for the original observations used for the model fit.
 #' Ignored if using one of the residual plots (i.e. 'resid_hist')
+#'
 #' @param ... Further arguments passed to \code{\link{predict.mvgam}}
-#'   as well as to the PPC function specified in \code{type}.
-#' @inheritParams brms::prepare_predictions.brmsfit
+#'   as well as to the PPC function specified in \code{type}
 #'
 #' @return A ggplot object that can be further
 #'  customized using the \pkg{ggplot2} package.
@@ -966,8 +1011,9 @@ ppc.mvgam <- function(
 #' see the \code{\link[bayesplot:PPC-overview]{PPC}}
 #' documentation of the \pkg{\link[bayesplot:bayesplot-package]{bayesplot}}
 #' package.
+#'
 #' @seealso \code{\link{ppc}}, \code{\link{predict.mvgam}}
-#' @author Nicholas J Clark
+#'
 #' @examples
 #' \donttest{
 #' simdat <- sim_mvgam(seasonality = "hierarchical")
@@ -1042,9 +1088,10 @@ ppc.mvgam <- function(
 #' pp_check(mod, prefix = "ppd")
 #' }
 #'
-#' @importFrom bayesplot pp_check
 #' @export pp_check
+#'
 #' @author Nicholas J Clark
+#'
 #' @export
 pp_check.mvgam <- function(
   object,
